import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

const styles = {"component":"checkbox__component_ic4xs","start":"checkbox__start_ic4xs","center":"checkbox__center_ic4xs","addons":"checkbox__addons_ic4xs","block":"checkbox__block_ic4xs","box":"checkbox__box_ic4xs","checkedIcon":"checkbox__checkedIcon_ic4xs","s":"checkbox__s_ic4xs","disabled":"checkbox__disabled_ic4xs","inactive":"checkbox__inactive_ic4xs","checked":"checkbox__checked_ic4xs","indeterminate":"checkbox__indeterminate_ic4xs","label":"checkbox__label_ic4xs","hint":"checkbox__hint_ic4xs","focused":"checkbox__focused_ic4xs","content":"checkbox__content_ic4xs","errorMessage":"checkbox__errorMessage_ic4xs","indeterminateLine":"checkbox__indeterminateLine_ic4xs"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, hiddenInput = false, error, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.inactive]: inactive,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        !hiddenInput && (React.createElement("input", { type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ...restProps })),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
